@@ -41,14 +41,6 @@ def test_drop_database(query_factory, execution):
     execution.PSqlCmdRunner.return_value.execute.assert_called_once_with(query_factory.get_drop_database.return_value)
 
 
-@patch("pynonymizer.database.postgres.execution", autospec=True)
-@patch("pynonymizer.database.postgres.query_factory", autospec=True)
-def test_connection(query_factory, execution):
-    # test_connection should return the cmd runner's test output (bool)
-    provider = PostgreSqlProvider("1.2.3.4", "root", "password", "db_name")
-    assert provider.test_connection() == execution.PSqlCmdRunner.return_value.test.return_value
-
-
 @patch("pynonymizer.database.postgres.execution", autospec=True)
 @patch("pynonymizer.database.postgres.query_factory", autospec=True)
 @patch("pynonymizer.database.postgres.resolve_input")
@@ -149,7 +141,7 @@ def test_after_script_run(query_factory,execution):
 
 @patch("pynonymizer.database.postgres.execution")
 @patch("pynonymizer.database.postgres.query_factory")
-def test_anonymize_database(query_factory, execution, simple_strategy, simple_strategy_update_fake_column, simple_strategy_update, simple_strategy_trunc):
+def test_anonymize_database(query_factory, execution, simple_strategy, simple_strategy_update_fake_column, simple_strategy_update, simple_strategy_trunc, simple_strategy_delete):
     manager = Mock()
     manager.attach_mock(execution, "execution")
 
@@ -166,6 +158,7 @@ def test_anonymize_database(query_factory, execution, simple_strategy, simple_st
     query_factory.get_insert_seed_row.assert_has_calls( ([call(*seed_table_qualifier_map)] * 200) )
 
     query_factory.get_truncate_table.assert_called_once_with(simple_strategy_trunc)
+    query_factory.get_delete_table.assert_called_once_with(simple_strategy_delete)
     query_factory.get_update_table.assert_called_once_with("_pynonymizer_seed_fake_data", simple_strategy_update)
     query_factory.get_drop_seed_table.assert_called_once_with("_pynonymizer_seed_fake_data")
 
