@@ -14,9 +14,9 @@ from pynonymizer.strategy.update_column import (
 import pynonymizer.database.postgres.query_factory as query_factory
 
 """
-These tests are brittle and based on the actual SQL generatedColumnStrategyTypes. 
+These tests are brittle and based on the actual SQL generatedColumnStrategyTypes.
 The sentiment is to test the 'meaning' of the SQL, rather than the actual formatting, so it may be prudent to replace
-these tests with some form of parsing or pattern matching. 
+these tests with some form of parsing or pattern matching.
 
 The general idea, however, is that by keeping the queryfactory separate from the provider, it will not change often,
 and the sql returned should be very stable.
@@ -26,6 +26,10 @@ and the sql returned should be very stable.
 def test_get_truncate_table(simple_strategy_trunc):
     assert query_factory.get_truncate_table(simple_strategy_trunc) == "TRUNCATE TABLE truncate_table CASCADE;"
 
+# deletes are identical to truncates because postgres has cascading truncs
+def test_get_delete_table(simple_strategy_delete):
+    assert query_factory.get_delete_table(simple_strategy_delete) == "TRUNCATE TABLE delete_table CASCADE;"
+
 
 def test_get_schema_truncate_table(simple_strategy_schema_trunc):
     assert query_factory.get_truncate_table(simple_strategy_schema_trunc) == "TRUNCATE TABLE schema.truncate_schema_table CASCADE;"
@@ -61,6 +65,12 @@ def int_fake_column_generator():
         get_data_type=Mock(return_value=FakeDataType.INT),
         get_value=Mock(return_value=645)
     )
+@pytest.fixture
+def uuid_fake_column_generator():
+    return Mock(
+        get_data_type=Mock(return_value=FakeDataType.STRING),
+        get_value=Mock(return_value="d4b7d972-99c9-4c0f-83c0-4cf2c63fd6ed")
+    )
 
 
 @pytest.fixture
@@ -72,6 +82,9 @@ def fake_update_column_str_first_name(str_fake_column_generator):
 def fake_update_column_int_last_name(int_fake_column_generator):
     return FakeUpdateColumnStrategy("test_column2",int_fake_column_generator, "last_name")
 
+@pytest.fixture
+def fake_update_column_uuid_user_id(uuid_fake_column_generator):
+    return FakeUpdateColumnStrategy("test_column7", uuid_fake_column_generator, "user_id", sql_type="UUID")
 
 @pytest.fixture
 def empty_strategy():
@@ -108,10 +121,11 @@ def qualifier_column_map(fake_update_column_str_first_name,fake_update_column_in
 
 
 @pytest.fixture
-def column_strategy_list(fake_update_column_str_first_name,fake_update_column_int_last_name,empty_strategy,ulogin_strategy, uemail_strategy,literal_strategy):
+def column_strategy_list(fake_update_column_str_first_name,fake_update_column_int_last_name,fake_update_column_uuid_user_id,empty_strategy,ulogin_strategy, uemail_strategy,literal_strategy):
     return [
         fake_update_column_str_first_name,
         fake_update_column_int_last_name,
+        fake_update_column_uuid_user_id,
         empty_strategy,
         ulogin_strategy,
         uemail_strategy,
@@ -169,12 +183,13 @@ def test_get_update_table_fake_column(column_strategy_list):
 
     assert update_table_all == [
             "UPDATE anon_table AS \"updatetarget\" SET "
-            "test_column1 = ( SELECT first_name FROM seed_table WHERE \"updatetarget\"=\"updatetarget\" ORDER BY RANDOM() LIMIT 1),"
-            "test_column2 = ( SELECT last_name FROM seed_table WHERE \"updatetarget\"=\"updatetarget\" ORDER BY RANDOM() LIMIT 1),"
-            "test_column3 = (''),"
-            "test_column4 = ( SELECT md5(random()::text) WHERE \"updatetarget\"=\"updatetarget\" ),"
-            "test_column5 = ( SELECT CONCAT(md5(random()::text), '@', md5(random()::text), '.com') WHERE \"updatetarget\"=\"updatetarget\" ),"
-            "test_column6 = RANDOM();"
+            "\"test_column1\" = ( SELECT first_name FROM seed_table WHERE \"updatetarget\"=\"updatetarget\" ORDER BY RANDOM() LIMIT 1),"
+            "\"test_column2\" = ( SELECT last_name FROM seed_table WHERE \"updatetarget\"=\"updatetarget\" ORDER BY RANDOM() LIMIT 1),"
+            "\"test_column7\" = ( SELECT user_id::UUID FROM seed_table WHERE \"updatetarget\"=\"updatetarget\" ORDER BY RANDOM() LIMIT 1),"
+            "\"test_column3\" = (''),"
+            "\"test_column4\" = ( SELECT md5(random()::text) WHERE \"updatetarget\"=\"updatetarget\" ),"
+            "\"test_column5\" = ( SELECT CONCAT(md5(random()::text), '@', md5(random()::text), '.com') WHERE \"updatetarget\"=\"updatetarget\" ),"
+            "\"test_column6\" = RANDOM();"
             ]
 
 
@@ -185,5 +200,5 @@ def test_get_update_table_literal(literal_strategy):
     ]))
 
     assert result_queries == [
-        "UPDATE anon_table AS \"updatetarget\" SET literal_column = RANDOM();"
-    ]
\ No newline at end of file
+        "UPDATE anon_table AS \"updatetarget\" SET \"literal_column\" = RANDOM();"
+    ]
